@@ -189,12 +189,12 @@ def _resources(df):
     # since last mean process time
     duration = round(df.process.mean(), 0)
     last = (
-        df[df.end > (time.time() - duration)].groupby(by=by).genation.count().nlargest()
+        df[df.end > (time.time() - duration)].groupby(by=by).generation.count().nlargest()
     )
 
     # print some columns
     left = Section(
-        df.groupby(by=by).genation.count().nlargest().to_string(),
+        df.groupby(by=by).generation.count().nlargest().to_string(),
         title="Most active (all time)",
     )
     if last.empty:
